@@ -109,12 +109,18 @@ starting the timer.')
 in''')
     parser.add_option('-a', '--at', dest='at', type='string',
                       help='''Set time of clock-in''')
+    parser.add_option('-r', '--resume', dest='resume', action='store_true',
+                      default=False, help='''Clocks in with status of \
+last active period''')
     opts, args = parser.parse_args(args=args)
     if opts.switch:
         sheet = opts.switch
         switch(db, [sheet])
     else:
         sheet = dbutil.get_current_sheet(db)
+    if opts.resume and args:
+        parser.error('"--resume" already sets a note, and is incompatible \
+with arguments.')
     timestamp = cmdutil.parse_date_time_or_now(opts.at)
     if opts.out:
         clock_out(db, timestamp=timestamp)
@@ -122,9 +128,14 @@ in''')
     if running is not None:
         raise SystemExit, 'error: timesheet already active'
     most_recent_clockout = dbutil.get_most_recent_clockout(db, sheet)
-    if most_recent_clockout and timestamp < most_recent_clockout:
-        raise SystemExit, 'error: time periods could end up overlapping'
     description = u' '.join(args) or None
+    if most_recent_clockout:
+        (previous_timestamp, previous_description) = most_recent_clockout
+        if timestamp < previous_timestamp:
+            raise SystemExit, \
+                  'error: time periods could end up overlapping'
+        if opts.resume:
+            description = previous_description
     db.execute(u'''
     insert into entry (
         sheet, start_time, description, extra
@@ -246,7 +257,7 @@ number of entries of the timesheet.')
     # optimization: check that the given timesheet is not already
     # current. updates are far slower than selects.
     if dbutil.get_current_sheet(db) != sheet:
-            db.execute(u'''
+        db.execute(u'''
         update
             meta
         set
@@ -256,7 +267,7 @@ number of entries of the timesheet.')
         ''', (args[0],))
 
     if opts.verbose:
-        entry_count = dbutil.get_entry_count(db)
+        entry_count = dbutil.get_entry_count(db, sheet)
         if entry_count == 0:
             print u'switched to empty timesheet "%s"' % sheet
         else:
@@ -276,6 +287,8 @@ the period that the out command ends.')
     parser.add_option('-a', '--at', dest='at',
                       help='Set time of clock-out')
     opts, args = parser.parse_args(args=args)
+    if args:
+        parser.error('"t out" takes no arguments.')
     clock_out(db, opts.at, opts.verbose)
 
 def clock_out(db, at=None, verbose=False, timestamp=None):
@@ -353,6 +366,9 @@ timesheet instead.''')
     parser.add_option('-s', '--simple', dest='simple',
                       action='store_true', help='Only display the name \
 of the current timesheet.')
+    parser.add_option('-n', '--notes', dest='notes',
+                      action='store_true', help='Only display the notes \
+associated with the current period.')
     opts, args = parser.parse_args(args=args)
 
     if opts.simple:
@@ -365,21 +381,26 @@ of the current timesheet.')
     else:
         sheet = dbutil.get_current_sheet(db)
 
-    entry_count = dbutil.get_entry_count(db)
+    entry_count = dbutil.get_entry_count(db, sheet)
     if entry_count == 0:
         raise SystemExit, '%(prog)s: error: sheet is empty. For program \
 usage, see "%(prog)s --help".' % {'prog': os.path.basename(sys.argv[0])}
 
     running = dbutil.get_active_info(db, sheet)
+    notes = ''
     if running is None:
         active = 'not active'
     else:
         duration = str(timedelta(seconds=running[0]))
         if running[1]:
-            active = '%s (%s)' % (duration, running[1].rstrip('.'))
+            notes = running[1].rstrip('.')
+            active = '%s (%s)' % (duration, notes)
         else:
             active = duration
-    print '%s: %s' % (sheet, active)
+    if opts.notes:
+        print notes
+    else:
+        print '%s: %s' % (sheet, active)
 
 @command('display timesheet, by default the current one',
          aliases=('export', 'format', 'show'))
